==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebIconDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebIconDescription } from "./WebIconDescription";
/**
 * @hidden
 */
var WebIconDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebIconDescriptionMetadata, _super);
    function WebIconDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebIconDescriptionMetadata.b = function (a) {
        if (WebIconDescriptionMetadata.a == null) {
            WebIconDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebIconDescriptionMetadata.c(WebIconDescriptionMetadata.a);
        }
        if (a.j(WebIconDescriptionMetadata.a)) {
            return;
        }
        a.y(WebIconDescriptionMetadata.a);
    };
    WebIconDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Icon");
        a.item("__tagNameWC", "String:igc-icon");
        a.item("IconName", "(wc:Name)String");
        a.item("Collection", "String");
        a.item("Mirrored", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebIconDescriptionMetadata.d = function (a) {
        WebIconDescriptionMetadata.b(a);
        a.aa("WebIcon", function () { return new WebIconDescription(); });
        a.z("WebIcon", WebIconDescriptionMetadata.a);
    };
    WebIconDescriptionMetadata.$t = markType(WebIconDescriptionMetadata, 'WebIconDescriptionMetadata');
    WebIconDescriptionMetadata.a = null;
    return WebIconDescriptionMetadata;
}(Base));
export { WebIconDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebIconDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebIconDescription } from "./WebIconDescription";
/**
 * @hidden
 */
var WebIconDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebIconDescriptionMetadata, _super);
    function WebIconDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebIconDescriptionMetadata.b = function (a) {
        if (WebIconDescriptionMetadata.a == null) {
            WebIconDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebIconDescriptionMetadata.c(WebIconDescriptionMetadata.a);
        }
        if (a.k(WebIconDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebIconDescriptionMetadata.a);
    };
    WebIconDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Icon");
        a.item("__tagNameWC", "String:igc-icon");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("IconName", "(wc:Name)String");
        a.item("Collection", "String");
        a.item("Mirrored", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebIconDescriptionMetadata.d = function (a) {
        WebIconDescriptionMetadata.b(a);
        a.ac("WebIcon", function () { return new WebIconDescription(); });
        a.ab("WebIcon", WebIconDescriptionMetadata.a);
    };
    WebIconDescriptionMetadata.$t = markType(WebIconDescriptionMetadata, 'WebIconDescriptionMetadata');
    WebIconDescriptionMetadata.a = null;
    return WebIconDescriptionMetadata;
}(Base));
export { WebIconDescriptionMetadata };
